@@ -1,6 +1,7 @@
 import sys
 
 DEFAULT_PROTOCOL = 2
+DEFAULT_ENCODING = "latin1"
 
 if sys.version_info.major == 3:
     # Helper functions and classes to make pickle backward-compatible with python2
@@ -8,26 +9,9 @@ if sys.version_info.major == 3:
     import pickle
     from functools import partial
 
-    # Vanilla implementation of the unpickler that we'll subclass.
-    VanillaUnpickler = pickle._Unpickler
-
-    # Here's our unpickler that overwrites "BUILD" opcode. It takes data from the
-    # stack, and if it's a dict, converts all the keys from bytes to strings.
-    class CompatUnpickler(VanillaUnpickler):
-        def load_build(self):
-            state = self.stack[-1]
-            if isinstance(state, dict):
-                new_state = {to_str(k): v for k, v in state.items()}
-                self.stack[-1] = new_state
-            VanillaUnpickler.load_build(self)
-
-    # We also need to explicitly register our own handler in the dispatcher, because
-    # otherwise a method of the superclass will be called
-    CompatUnpickler.dispatch[pickle.BUILD[0]] = CompatUnpickler.load_build
-
-    # Backward-compatible load and loads, that use "bytes" as a default encoding.
-    compat_load = partial(pickle._load, encoding="bytes")
-    compat_loads = partial(pickle._loads, encoding="bytes")
+    # Backward-compatible load and loads, that use "latin1" as a default encoding.
+    compat_load = partial(pickle._load, encoding=DEFAULT_ENCODING)
+    compat_loads = partial(pickle._loads, encoding=DEFAULT_ENCODING)
 
     # Backward-compatible dump and dumps, that use the second version of the protocol.
     def compat_dump(obj, file, protocol=None, fix_imports=True, buffer_callback=None):
@@ -47,20 +31,9 @@ if sys.version_info.major == 3:
             buffer_callback=buffer_callback,
         )
 
-    def to_str(obj):
-        """
-        Helper function to convert bytes to string.
-
-        We use ASCII encoding, because in the context when it's called, we don't expect
-        anything that's not ascii-compatible, and we want to fail earily.
-        """
-        if isinstance(obj, bytes):
-            return obj.decode("ASCII")
-        return obj
-
     # Backward-compatible versions of functions and classes
     compat = {
-        "Unpickler": CompatUnpickler,
+        "Unpickler": pickle.Unpickler,
         "load": compat_load,
         "loads": compat_loads,
         "dump": compat_dump,
@@ -71,7 +44,7 @@ else:
     import new
     import pickle
 
-    # Vanilla implementation of teh objects that we overwrite.
+    # Vanilla implementation of the objects that we overwrite.
     VanillaUnpickler = pickle.Unpickler
     vanilla_dump = pickle.dump
     vanilla_dumps = pickle.dumps
